print("import: 'jupyter_nbextensions_configurator'")
import jupyter_nbextensions_configurator

print("import: 'jupyter_nbextensions_configurator.application'")
import jupyter_nbextensions_configurator.application

